@@ -138,6 +138,7 @@ $dtc_database = array(
 			"addr_secondary_dns" => "varchar(255) NOT NULL default 'ns2.example.com' ",
 			"ip_slavezone_dns_server" => "varchar(16) NOT NULL default '192.168.0.3' ",
 			"ip_allowed_dns_transfer" => "varchar(255) NOT NULL default '192.168.0.1' ",
+			"default_zones_ttl" => "int(11) NOT NULL default '7200'",
 			"domainkey_publickey_filepath" => "varchar(255) NULL default '/var/lib/dkfilter/public.key' ",
 			"main_domain" => "varchar(128) NOT NULL default 'gplhost.com' ",
 			"404_subdomain" => "varchar(128) NOT NULL default '404' ",
@@ -302,7 +303,8 @@ $dtc_database = array(
 			"ttl" => "int NULL default '7200' ",
 			"stats_login" => "varchar(32) NOT NULL default ''",
   			"stats_pass" => "varchar(16) NOT NULL default ''",
-  			"stats_subdomain" => " enum('yes','no') NOT NULL default 'no'"
+  			"stats_subdomain" => " enum('yes','no') NOT NULL default 'no'",
+  			"wildcard_dns" => "enum('yes','no') NOT NULL default 'no'"
 			),
 		"primary" => "(id)",
 		"keys" => array(
@@ -621,6 +623,7 @@ $dtc_database = array(
 			"time" => "time NOT NULL default '00:00:00'",
 			"maxmind_output" => "text NOT NULL",
 			"last_used_lang" => "varchar(32) NOT NULL default 'en_US'",
+			"add_service" => "enum('yes','no') NOT NULL default 'no'"
 			),
 		"primary" => "(id)"
 		),
@@ -873,7 +876,10 @@ $dtc_database = array(
 			"enets_rate" => "float(6,2) NOT NULL default '0.00'",
 			"use_maxmind" => "enum('yes','no') NOT NULL default 'no'",
 			"maxmind_login" => "varchar(255) NOT NULL default ''",
-			"maxmind_license_key" => "varchar(255) NOT NULL default ''"
+			"maxmind_license_key" => "varchar(255) NOT NULL default ''",
+			"use_webmoney" => "enum('yes','no') NOT NULL default 'no'",
+			"webmoney_license_key" => "varchar(255) NOT NULL default ''",
+			"webmoney_wmz" => "varchar(255) NOT NULL default ''"
 			),
 		"keys" => array(
 			"unicrow" => "(unicrow)"
@@ -1006,6 +1012,20 @@ $dtc_database = array(
 			"ownerindex" => "(owner)"
 			)
 		),
+	"vps_ip" => array(
+		"vars" => array(
+			"id" => "int(11) NOT NULL auto_increment",
+			"vps_server_hostname" => "varchar(255) NOT NULL default ''",
+			"vps_xen_name" => "varchar(64) NOT NULL default ''",
+			"ip_addr" => "varchar(16) NOT NULL default ''",
+			"rdns_addr" => "varchar(255) NOT NULL default 'gplhost.com'",
+			"available" => "enum('yes','no') NOT NULL default 'yes'"
+			),
+		"unique" => array(
+			"ip_addr" => "(ip_addr)"
+			),
+		"primary" => "(id)",
+		),
         "vps_server" => array(
                 "vars" => array(
                         "id" => "int(11) NOT NULL auto_increment",
