@@ -42,8 +42,12 @@ if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "edit_vps_config"){
 	$r = mysql_query($q)or die("Cannot execute query \"$q\" line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 }
 
-if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "delete_a_vps"){
-	$q = "SELECT * FROM $pro_mysql_vps_table WHERE id='".$_REQUEST["id"]."';";
+function deleteVPS($id){
+	global $pro_mysql_vps_table;
+	global $pro_mysql_vps_ip_table;
+	global $pro_mysql_vps_stats_table;
+
+	$q = "SELECT * FROM $pro_mysql_vps_table WHERE id='$id';";
 	$r = mysql_query($q)or die("Cannot execute query \"$q\" line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 	$n = mysql_num_rows($r);
 	if($n != 1){
@@ -60,10 +64,15 @@ if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "delete_a_vps"){
 	$r = mysql_query($q)or die("Cannot execute query \"$q\" line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 
 	remoteVPSAction($vps["vps_server_hostname"],$vps["vps_xen_name"],"destroy_vps");
+	remoteVPSAction($vps["vps_server_hostname"],$vps["vps_xen_name"],"kill_vps_disk");
 
 	VPS_Server_Subscribe_To_Lists($vps["vps_server_hostname"]);
 }
 
+if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "delete_a_vps"){
+	deleteVPS($_REQUEST["id"]);
+}
+
 if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "vps_server_list_remove"){
 	$q = "SELECT * FROM $pro_mysql_vps_server_table WHERE id='".$_REQUEST["edithost"]."';";
 	$r = mysql_query($q)or die("Cannot execute query \"$q\" line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());;
@@ -306,50 +315,4 @@ if(isset($_REQUEST["delete_admin_user"]) && $_REQUEST["delete_admin_user"] != ""
 	DTCdeleteAdmin($_REQUEST["delete_admin_user"]);
 }
 
-//////////////////////////////
-// MySQL account management //
-//////////////////////////////
-if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "delete_mysql_user"){
-	deleteMysqlUserAndDB($adm_login);
-}
-
-// ?adm_login=test&adm_pass=test&action=create_mysql_account
-if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "create_mysql_account"){
-	mysql_select_db("mysql")or die("Cannot select db mysql for account management !!!");
-	$query = "INSERT INTO `user` (`Host`, `User`, `Password`, `Select_priv`, `Insert_priv`,
-	`Update_priv`, `Delete_priv`, `Create_priv`, `Drop_priv`, `Reload_priv`, `Shutdown_priv`,
-	`Process_priv`, `File_priv`, `Grant_priv`, `References_priv`, `Index_priv`, `Alter_priv`)
-	VALUES ('localhost', '$adm_login', PASSWORD('$adm_pass'), 'N', 'N', 'N', 'N', 'N', 'N', 'N', 'N', 'N',
-	'N', 'N', 'N', 'N', 'N')";
-	mysql_query($query)or die("Cannot execute query \"$query\" !!!");
-	mysql_select_db($conf_mysql_db)or die("Cannot select db \"$conf_mysql_db\"	!!!");
-}
-
-// adm_login=test&adm_pass=test&new_mysql_database_name=test2&new_mysql_database=Ok
-if(isset($_REQUEST["new_mysql_database"]) && $_REQUEST["new_mysql_database"] == "Ok"){
-	mysql_select_db("mysql")or die("Cannot select db mysql for account management !!!");
-	$query = "CREATE DATABASE ".$_REQUEST["new_mysql_database_name"].";";
-	mysql_query($query)or die("Cannot execute query \"$query\" !!!");
-
-	$query = "INSERT INTO `db` (`Host`, `Db`, `User`, `Select_priv`, `Insert_priv`, `Update_priv`, `Delete_priv`, `Create_priv`,
-	`Drop_priv`, `Grant_priv`, `References_priv`, `Index_priv`, `Alter_priv`) VALUES ('localhost', '".$_REQUEST["new_mysql_database_name"]."',
-	'$adm_login', 'Y', 'Y', 'Y', 'Y', 'Y', 'Y', 'N', 'Y', 'Y', 'Y')";
-	mysql_query($query)or die("Cannot execute query \"$query\" !!!");
-
-	mysql_query("FLUSH PRIVILEGES");
-
-	mysql_select_db($conf_mysql_db)or die("Cannot select db \"$conf_mysql_db\"	!!!".mysql_error());
-}
-// ?adm_login=test&adm_pass=test&action=delete_one_db&db_name=azerty2
-if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "delete_one_db"){
-	mysql_select_db("mysql")or die("Cannot select db mysql for account management !!!");
-
-	$query = "DELETE FROM db WHERE User='$adm_login' AND Db='".$_REQUEST["db_name"]."';";
-	mysql_query($query)or die("Cannot execute query \"$query\" !!!".mysql_error());
-	$query = "DROP DATABASE ".$_REQUEST["db_name"].";";
-	mysql_query($query)or die("Cannot execute query \"$query\" !!!".mysql_error());
-	mysql_query("FLUSH PRIVILEGES");
-
-	mysql_select_db($conf_mysql_db)or die("Cannot select db \"$conf_mysql_db\"	!!!");
-}
 ?>
