@@ -13,7 +13,8 @@ addr_primary_dns varchar(255) NOT NULL default 'ns1.example.com',
 addr_secondary_dns varchar(255) NOT NULL default 'ns2.example.com',
 ip_slavezone_dns_server varchar(16) NOT NULL default '192.168.0.3',
 ip_allowed_dns_transfer varchar(255) NOT NULL default '192.168.0.1',
-domainkey_publickey_filepath varchar(255) NOT NULL default '/var/lib/dkfilter/public.key',
+domainkey_publickey_filepath varchar(255) NOT NULL default '/var/lib/dkimproxy/public.key',
+default_zones_ttl int(11) NOT NULL default '7200',
 main_domain varchar(128) NOT NULL default 'gplhost.com',
 404_subdomain varchar(128) NOT NULL default '404',
 administrative_site varchar(255) NOT NULL default 'dtc.example.com',
@@ -83,9 +84,9 @@ shared_renewal_lastwarning varchar (64) NOT NULL default '25',
 shared_renewal_shutdown varchar (64) NOT NULL default '28',
 webalizer_country_graph enum('yes','no') NOT NULL default 'no',
 apache_version varchar (16) NOT NULL default '1',
-dtc_system_uid varchar (16) NOT NULL default '65534',
+dtc_system_uid varchar (16) NOT NULL default '1001',
 dtc_system_username varchar (64) NOT NULL default 'dtc',
-dtc_system_gid varchar (16) NOT NULL default '65534',
+dtc_system_gid varchar (16) NOT NULL default '1001',
 dtc_system_groupname varchar (64) NOT NULL default 'nogroup',
 selling_conditions_url varchar (255) NOT NULL default 'none',
 user_mysql_type enum('localhost','distant') NOT NULL default 'localhost',
