@@ -1,36 +1,22 @@
 <?php
 
-
-
 function login_emailpanel_form(){
-	global $txt_login_login;
-	global $txt_login_pass;
-	global $txt_use_text_menu;
-	global $txt_login_title;
-	
 	global $conf_skin;
-
-	global $lang;
 	
-	global $txt_goto_client_panel;
-	global $txt_go_to_login;
-	
-	$HTML_admin_edit_data = "<a href=\"/dtc\">".$txt_goto_client_panel[$lang]."</a>
+	$HTML_admin_edit_data = "<a href=\"/dtc\">". _("Go to client panel") ."</a>
 <form action=\"".$_SERVER["PHP_SELF"]."\" method=\"post\">
 <table>
 <tr>
-	<td align=\"right\">".$txt_login_login[$lang]."</td>
+	<td align=\"right\">". _("Login: ") ."</td>
 	<td><input type=\"text\" name=\"adm_email_login\" value=\"\"></td>
 </tr><tr>
-	<td align=\"right\">".$txt_login_pass[$lang]."</td>
+	<td align=\"right\">". _("Password: ") ."</td>
 	<td><input type=\"password\" name=\"adm_email_pass\" value=\"\"></td>
 </tr><tr>
-	<td></td><td><input type=\"submit\" name=\"Login\" value=\"".$txt_go_to_login[$lang]."\">
+	<td></td><td><input type=\"submit\" name=\"Login\" value=\"". _("Ok") ."\">
 </td></tr>
 </table></form>";
 
-//	$login_skined = skin($conf_skin,$HTML_admin_edit_data,$txt_login_title[$lang]);
-//	return $login_skined;
 	return $HTML_admin_edit_data;
 }
 
@@ -45,4 +31,4 @@ function layout_login_and_languages($login_skined,$language_selection_skined){
 </tr></table>";
 }
 
-?>
\ No newline at end of file
+?>
