@@ -43,6 +43,30 @@ function domainNamePopup($domain_name=""){
 	return $out;
 }
 
+function vpsLocationSelector(){
+	global $pro_mysql_vps_ip_table;
+	global $pro_mysql_vps_server_table;
+
+	$q = "SELECT $pro_mysql_vps_server_table.hostname,$pro_mysql_vps_server_table.location
+	FROM $pro_mysql_vps_ip_table,$pro_mysql_vps_server_table
+	WHERE $pro_mysql_vps_ip_table.vps_server_hostname=$pro_mysql_vps_server_table.hostname
+	AND $pro_mysql_vps_ip_table.available='yes'
+	GROUP BY $pro_mysql_vps_server_table.location;";
+	$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
+	$n = mysql_num_rows($r);
+	$vps_location_popup = "<option value=\"-1\">Please select!</optioon>";
+	for($i=0;$i<$n;$i++){
+		$a = mysql_fetch_array($r);
+		if(isset($_REQUEST["vps_server_hostname"]) && $_REQUEST["vps_server_hostname"] == $a["hostname"]){
+			$selected = " selected ";
+		}else{
+			$selected = "";
+		}
+		$vps_location_popup .= "<option value=\"".$a["hostname"]."\" $selected>".$a["location"]."</optioon>";
+	}
+	return $vps_location_popup;
+}
+
 function findLastUsedLangByUser($adm_login){
 	global $pro_mysql_admin_table;
 	global $pro_mysql_new_admin_table;
@@ -174,9 +198,9 @@ function HTTP_Post($URL,$data, $referrer=""){
 }
 
 function logPay($txt){
-	$fp = fopen("/tmp/paylog.txt","a");
-	fwrite($fp,$txt."\n");
-	fclose($fp);
+//	$fp = fopen("/tmp/paylog.txt","a");
+//	fwrite($fp,$txt."\n");
+//	fclose($fp);
 	echo $txt."<br>";
 }
 
@@ -292,7 +316,7 @@ function checkSubdomainFormat($name){
 // Check if a string is an ssh key
 // TO BE DONE!!!
 function isSSHKey($ssh_key){
-	if(ereg("^ssh-[rd]s[as] [a-zA-Z+/=]+\$",$ssh_key)){
+	if(ereg("^ssh-[rd]s[as] ([.a-zA-Z0-9+/=]+)\$",$ssh_key)){
 		return true;
 	}else{
 		return false;
@@ -649,6 +673,11 @@ function addDomainToUser($adm_login,$adm_pass,$domain_name,$domain_password=""){
 
 	// Create subdirectorys & html front page
 	if($conf_demo_version == "no"){
+
+		if(!file_exists($admin_path)){
+			mkdir($admin_path, 0755);
+		}
+
 		make_new_adm_domain_dir("$admin_path/$domain_name");
 		exec("cp -fulpRv $conf_chroot_path/* $admin_path/$domain_name/subdomains/www");
 		// create a link so that the user can log in via SSH to $admin_path or $admin_path/$domain_name
