@@ -7,7 +7,7 @@ function helpLink($link){
 	}else{
 		$helpimg_src = "gfx/help.png";
 	}
-	$out = "<a target=\"_blank\" href=\"http://dtcsupport.gplhost.com/pmwiki/$link\"><img border=\"0\" src=\"$helpimg_src\"</a>";
+	$out = "<a target=\"_blank\" href=\"http://dtcsupport.gplhost.com/$link\"><img border=\"0\" src=\"$helpimg_src\"</a>";
 	return $out;
 }
 
@@ -360,7 +360,11 @@ function dtcDatagrid($dsc){
 	if(isset($dsc["where_condition"])){
 		$where = " WHERE ".$dsc["where_condition"]." ";
 	}else{
-		$where = "";
+		if( isset($dsc["print_where_condition"]) ){
+			$where = " WHERE ".$dsc["print_where_condition"];
+		}else{
+			$where = "";
+		}
 	}
 	if(isset($dsc["order_by"])){
 		$order_by = " ORDER BY ".$dsc["order_by"]." ";
@@ -651,6 +655,7 @@ function dtcDatagrid($dsc){
 // "type" => "popup" -> The control is a popup
 // "values" => array("yes","no") -> Values of the popup (in display order)
 // [display_replace] => array(... -> Values to replace in the display (can be smaller than the values array)
+// "max_value_positive" => INT -> Check against an INT max value for a field
 
 // This function is to be used for the user panel, it has field content check & validations plus addslashes
 
@@ -844,6 +849,20 @@ function dtcListItemsEdit($dsc){
 						}
 					}
 					break;
+				case "max_value_2096":
+					if( !isset($dsc["cols"][ $keys[$i] ]["can_be_empty"])
+								|| $dsc["cols"][ $keys[$i] ]["can_be_empty"] != "yes"
+								|| $_REQUEST[ $keys[$i] ] != ""){
+						if( !isRandomNum($_REQUEST[ $keys[$i] ]) ){
+							$commit_flag = "no";
+							$commit_err .= $keys[$i].": not a correct number format<br>";
+						}
+						if($_REQUEST[ $keys[$i] ] >= 2096){
+							$commit_flag = "no";
+							$commit_err .= $keys[$i].": is greater or equal than the max value 2096<br>";
+						}
+					}
+					break;
 				default:
 					$commit_flag = "no";
 					$commit_err .= $keys[$i].": unknown field checking type (".$dsc["cols"][ $keys[$i] ]["check"].").<br>";
@@ -1108,6 +1127,20 @@ function dtcListItemsEdit($dsc){
 						}
 					}
 					break;
+				case "max_value_2096":
+					if( !isset($dsc["cols"][ $keys[$i] ]["can_be_empty"])
+								|| $dsc["cols"][ $keys[$i] ]["can_be_empty"] != "yes"
+								|| $_REQUEST[ $keys[$i] ] != ""){
+						if( !isRandomNum($_REQUEST[ $keys[$i] ]) ){
+							$commit_flag = "no";
+							$commit_err .= $keys[$i].": not a correct number format<br>";
+						}
+						if($_REQUEST[ $keys[$i] ] >= 2096){
+							$commit_flag = "no";
+							$commit_err .= $keys[$i].": is greater or equal than the max value 2096<br>";
+						}
+					}
+					break;
 				default:
 					$commit_flag = "no";
 					$commit_err .= $keys[$i].": unknown field checking type (".$dsc["cols"][ $keys[$i] ]["check"].").<br>";
