@@ -1,5 +1,5 @@
 <?php
-require("$dtcshared_path/inc/forms/lists_strings.php");
+
 /////////////////////////////////////////////////////
 // Subscribe / Unsubscribe users to a mailing list //
 /////////////////////////////////////////////////////
@@ -105,7 +105,7 @@ if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "subscribe_new_user"){
 if(isset($_REQUEST["addnewlisttodomain"]) && $_REQUEST["addnewlisttodomain"] == "Ok"){
 	global $conf_mta_type;
 	global $conf_webmaster_email_addr;
-	global $lang;
+	global $conf_recipient_delimiter;
 
 	// This has to be done BEFORE any other sql requests using login/pass or edit_domain !!!
 	checkLoginPassAndDomain($adm_login,$adm_pass,$edit_domain);
@@ -121,14 +121,22 @@ if(isset($_REQUEST["addnewlisttodomain"]) && $_REQUEST["addnewlisttodomain"] ==
 		die("Owner is not a valid email !");
 	}
 
-	// Check if mail exists...
+	// Check if mail exists in mailbox database...
 	$test_query = "SELECT * FROM $pro_mysql_pop_table WHERE id='".$_REQUEST["newlist_name"]."' AND mbox_host='$edit_domain'";
 	$test_result = mysql_query ($test_query)or die("Cannot execute query \"$test_query\"");
 	$testnum_rows = mysql_num_rows($test_result);
 	if($testnum_rows != 0){
-		die("Mailbox allready exist in database then you can't use it for mailing list!");
+		die("Email address already exists in 'mailbox' database, it can't be used for the mailing list!");
 	}
 	
+	// Check if mail exists in mailalias database...
+	$test_query = "SELECT * FROM $pro_mysql_mailaliasgroup_table WHERE id='".$_REQUEST["newlist_name"]."' AND domain_parent='$edit_domain'";
+	$test_result = mysql_query ($test_query)or die("Cannot execute query \"$test_query\"");
+	$testnum_rows = mysql_num_rows($test_result);
+	if($testnum_rows != 0){
+		die("Email address already exists in 'mail alias' database, it can't be used for the mailing list!");
+	}
+
 	//Check if list exists...
 	$test_query = "SELECT * FROM $pro_mysql_list_table
 				WHERE name='".$_REQUEST["newlist_name"]."' AND domain='$edit_domain'";
@@ -136,7 +144,7 @@ if(isset($_REQUEST["addnewlisttodomain"]) && $_REQUEST["addnewlisttodomain"] ==
 				.__LINE__." file ".__FILE__. " sql said ".mysql_error());
 	$testnum_rows = mysql_num_rows($test_result);
 	if($testnum_rows != 0){
-		die("Mailing list already exist in database !");
+		die("Mailing list already exist in database!");
 	}
 
 	//Path of user's mailing lists
@@ -159,7 +167,7 @@ if(isset($_REQUEST["addnewlisttodomain"]) && $_REQUEST["addnewlisttodomain"] ==
 	$symlink = "ln -s ".$list_path."/".$folder_name." /var/spool/mlmmj/".$folder_name;
 	exec($symlink);
 
-	$cmd = "echo \"-\" > ".$list_path."/".$folder_name."/control/delimiter";
+	$cmd = "echo \"$conf_recipient_delimiter\" > ".$list_path."/".$folder_name."/control/delimiter";
         exec($cmd);
 
 	$fileName3 = $list_path.'/'.$folder_name.'/control/listaddress';
@@ -200,15 +208,28 @@ if(isset($_REQUEST["addnewlisttodomain"]) && $_REQUEST["addnewlisttodomain"] ==
 	}
 	
 	//dtc send an email to the owner
-	$subject = str_replace("#name#",$name,$txt_lists_email_subject[$lang]);
+	$subject = str_replace("#name#",$name, _("List #name#@#domain# successfully created!") );
 	$subject = str_replace("#domain#",$edit_domain,$subject);
-	$msg = str_replace("#name#",$name,$txt_lists_email_msg[$lang]);
+	$msg = str_replace("#name#",$name, _("You can control your mailing list by email or by control panel.
+You can send a email to the following addresses to execute the listed command:
+  
+  #name#-help@#domain# -> return the most common list's commands
+  #name#-list@#domain# -> return the subscribers's list
+  #name#-get-N@#domain# -> return the N list's message
+  #name#-owner@#domain# -> you can contact the list's owner by this address
+  #name#-unsubscribe@#domain# -> unsubscribe the email's sender from the list
+  #name#-subscribe@#domain# -> subscribe the email's sender to the list
+  #name#-subscribe-digest@#domain# -> subscribe the email's sender to the list's digest version
+  #name#-subscribe-nomail@#domain# -> subscribe the email's sender to the list's nomail version
+  
+For more informations go to mlmmj official web site at http://mlmmj.mmj.dk") );
 	$msg = str_replace("#domain#",$edit_domain,$msg);
 	$headers = "FROM: $conf_webmaster_email_addr\n";
 	$headers .= "Return-Path: $conf_webmaster_email_addr\n";
 	mail($owner, $subject, $msg, $headers);
 	
 	updateUsingCron("qmail_newu='yes',gen_qmail='yes'");
+	triggerMXListUpdate();
 }
 
 function tunablesBooleanRequestCheck($ctrl_path,$tunable_name){
@@ -444,6 +465,7 @@ if(isset($_REQUEST["modifylistdata"]) && $_REQUEST["modifylistdata"] == "Ok"){
 	tunablesValueRequestCheck($ctrl_dir,"verp");
 	tunablesValueRequestCheck($ctrl_dir,"maxverprecips");
 	tunablesValueRequestCheck($ctrl_dir,"delimiter");
+	tunablesValueRequestCheck($ctrl_dir,"bouncelife");
 	tunablesListRequestCheck($ctrl_dir,"owner");
 	tunablesTextareaRequestCheck($ctrl_dir,"customheaders");
 	tunablesListRequestCheck($ctrl_dir,"delheaders");
@@ -465,7 +487,7 @@ if(isset($_REQUEST["dellist"]) && $_REQUEST["dellist"] == "Del"){
 	
 	// Verify strings given
 	if(!isMailbox($_REQUEST["edit_mailbox"])){
-		die($_REQUEST["edit_mailbox"]." does not look like a mailbox login...");
+		die($_REQUEST["edit_mailbox"]. _(" does not look like a mailbox login...") );
 	}
 	
 	//Some vars
@@ -490,6 +512,12 @@ if(isset($_REQUEST["dellist"]) && $_REQUEST["dellist"] == "Del"){
 	unset($edit_mailbox);
 	mysql_query($adm_query)or die("Cannot execute query \"$adm_query\"");
 
+	if($edit_domain == $conf_main_domain){
+		$adm_query = "DELETE FROM $pro_mysql_vps_server_lists_table WHERE list_name='$name';";
+		mysql_query($adm_query)or die("Cannot execute query \"$adm_query\" line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+	}
+
+	triggerMXListUpdate();
 	updateUsingCron("gen_qmail='yes', qmail_newu='yes'");
 }
 
