@@ -24,6 +24,7 @@ $txt_langname = array(
 	"ru" => "UTF-8",
 	"de" => "UTF-8",
 	"zh" => "UTF-8",
+	"zh_TW" => "UTF-8",
 	"pl" => "UTF-8",
 	"se" => "iso-8859-15",
 	"pt" => "UTF-8",
@@ -42,8 +43,22 @@ if($panel_type!="cronjob"){
 	  $lang = $_SESSION["lang"];
         }
 	if(isset($_REQUEST["change_language"])){
-		if(!ereg("^([a-z0-9]+)([.a-z0-9-]*)([a-z0-9]+)\$",$_REQUEST["change_language"])){
-			die("Lang parameter not correct!!!");
+		// This is the case of xx_YY
+		if( strlen($_REQUEST["change_language"]) == 5){
+			$exploded_lang = explode("_",$_REQUEST["change_language"]);
+			if( !ereg("^([a-z0-9]+)([.a-z0-9-]*)([a-z0-9]+)\$",$exploded_lang[0]) ){
+				die("Lang parameter not correct line ".__LINE__." file ".__FILE__);
+			}
+			if( !ereg("^([A-Z0-9]+)([.A-Z0-9-]*)([A-Z0-9]+)\$",$exploded_lang[1]) ){
+				die("Lang parameter not correct line ".__LINE__." file ".__FILE__);
+			}
+		// This is the case of xx only and no _YY
+		}else if( strlen($_REQUEST["change_language"]) == 2){
+			if(!ereg("^([a-z0-9]+)([.a-z0-9-]*)([a-z0-9]+)\$",$_REQUEST["change_language"])){
+				die("Lang parameter not correct line ".__LINE__." file ".__FILE__);
+			}
+		}else{
+			die("Lang parameter not correct line ".__LINE__." file ".__FILE__);
 		}
 	        if($_REQUEST["change_language"] == "fr"){
 	                $lang = "fr";
@@ -69,6 +84,9 @@ if($panel_type!="cronjob"){
 		if($_REQUEST["change_language"] == "zh"){
 		  $lang = "zh";
 		}
+		if($_REQUEST["change_language"] == "zh_TW"){
+		  $lang = "zh_TW";
+		}
 		if($_REQUEST["change_language"] == "pl"){
 		  $lang = "pl";
 		}
@@ -121,7 +139,9 @@ if (!isset($lang)){
 }
 $charset = $txt_langname[$lang];
 $page_metacontent = "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=$charset\">";
-header("Content-type: text/html; charset=$charset");
+if($panel_type != "cronjob"){
+	header("Content-type: text/html; charset=$charset");
+}
 
 switch($lang){
 case "fr_FR":
@@ -153,6 +173,9 @@ case "zh_CN":
 case "zh":
 	$gettext_lang = "zh_CN.UTF-8";
 	break;
+case "zh_TW":
+	$gettext_lang = "zh_TW.UTF-8";
+	break;
 case "pl_PL":
 case "pl":
 	$gettext_lang = "pl_PL.UTF-8";
